@@ -19,6 +19,7 @@ Several components are included.
 # TODO: console_scripts for all of these
 
 import os
+import shutil
 import sys
 from cli import MakeItSoCLI
 from makeitso import ContentTemplate
@@ -57,6 +58,9 @@ class PythonModuleTemplate(PythonTemplate):
   def pre(self, variables, output):
     variables['project'] = variables['module'] = variables['main'] = self.output2name(output)
 
+  def post(self, variables, output):
+    shutil.move(os.path.join(output, '{{main.py}}'),
+                os.path.join(output, variables['main']))
 
 class PythonPackageTemplate(PythonTemplate):
   """
